(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     80520,       1700]*)
(*NotebookOutlinePosition[     81479,       1729]*)
(*  CellTagsIndexPosition[     81435,       1725]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Linear Regression", "Title"],

Cell["\<\
Michael Goerz
13.09.2005\
\>", "Text"],

Cell[CellGroupData[{

Cell["Preamble", "Section"],

Cell[CellGroupData[{

Cell["Options", "Subsubsection"],

Cell[BoxData[
    \(\(Off[General::"\<spell1\>"];\)\)], "Input"],

Cell[BoxData[
    \(<< \ Statistics`DataManipulation`\)], "Input"],

Cell[BoxData[
    \(<< \ Graphics`Graphics`\)], "Input"],

Cell[BoxData[
    \(<< Statistics`LinearRegression`\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Some Regular Expressions (As Reference)", "Subsubsection"],

Cell[TextData[{
  "The following shell commands can be useful for filtering datafiles:\n\n",
  StyleBox["grep '[.0-9]\\|^#\\|^[[:space:]]$' data.csv", "Program"],
  "\nThis leaves any lines with data, gnuplot comment lines, and blank lines\n\
\n",
  StyleBox["grep '[.0-9]\\|^[[:space:]]$' data.csv", "Program"],
  "\nThis leaves any lines with data, and blank lines\n\n",
  StyleBox["grep '[.0-9]' data.csv", "Program"],
  "\nThis leaves only lines with data"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Subsubsection"],

Cell["\<\
Data is loaded from the file 'data.csv'. The file ist assumed to \
contain three collumns, the x-value, the y-value, and the y-error\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dataset = ReadList["\<ass1.csv\>", {Real, Real, \ Real}]\)], "Input"],

Cell[BoxData[
    \({{0.`, 0.`, 3.`*^-7}, {1.`, 1.62`*^-6, 5.`*^-7}, {2.`, 3.39`*^-6, 
        4.`*^-7}, {3.`, 4.97`*^-6, 5.`*^-7}, {4.`, 6.62`*^-6, 5.`*^-7}, {5.`, 
        8.220000000000001`*^-6, 6.`*^-7}, {6.`, 9.81`*^-6, 6.`*^-7}, {7.`, 
        0.0000115`, 7.`*^-7}, {8.`, 0.000013200000000000002`, 6.`*^-7}, {9.`, 
        0.000014700000000000002`, 7.`*^-7}, {10.`, 0.0000164`, 
        7.`*^-7}}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions", "Section"],

Cell[CellGroupData[{

Cell["Standard Functions for Linear Regression", "Subsubsection"],

Cell[BoxData[
    RowBox[{\(LinReg[daten_]\), ":=", " ", "\[IndentingNewLine]", 
      RowBox[{"Module", "[", 
        RowBox[{\({x, y, \[CapitalDelta]y, \ 
            S\ , \[CapitalDelta]a0, \[CapitalDelta]b0, \ a0, \ b0, n, 
            Rsqared0, \[Chi]Squared0}\), ",", "\[IndentingNewLine]", 
          
          RowBox[{\(n = Length[daten]\), ";", 
            "\[IndentingNewLine]", \(x = Column[daten, 1]\), ";", 
            "\[IndentingNewLine]", \(y = Column[daten, \ 2]\), ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]y = Column[daten, 3]\), 
            ";", "\[IndentingNewLine]", \(S = \[Sum]\+\(i = 1\)\%n\( 
                        1\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\((x\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\) - \((\[Sum]\+\(i = 1\)\%n \
x\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)\^2\), ";", 
            "\[IndentingNewLine]", \(a0 = \(1\/S\) \((\[Sum]\+\(i = \
1\)\%n\(\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\
\(i = 1\)\%n y\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) - \[Sum]\+\(i = 1\)\%n\( 
                              x\[LeftDoubleBracket]
                              i\[RightDoubleBracket]\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\( x\
\[LeftDoubleBracket]i\[RightDoubleBracket]\ y\[LeftDoubleBracket]i\
\[RightDoubleBracket]\)\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\))\)\), ";", 
            RowBox[{
              RowBox[{Cell[""], "b0"}], 
              "=", \(\(1\/S\) \((\[Sum]\+\(i = 1\)\%n\( 
                            1\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\( x\[LeftDoubleBracket]i\
\[RightDoubleBracket]\ y\[LeftDoubleBracket]i\[RightDoubleBracket]\)\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) - \[Sum]\+\
\(i = 1\)\%n\( 
                              x\[LeftDoubleBracket]
                              i\[RightDoubleBracket]\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\(\(\
\ \)\(y\[LeftDoubleBracket]i\[RightDoubleBracket]\)\)\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\))\)\)}], ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]a0 = \@\(\(1\/S\) \
\(\[Sum]\+\(i = \
1\)\%n\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]\
y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)\)\), ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]b0 = \@\(\(1\/S\) \
\(\[Sum]\+\(i = 1\)\%n 1\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\)\)\), ";", 
            "\[IndentingNewLine]", \(Rsqared0 = 
              1 - \((\[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\
\[RightDoubleBracket] - a0 - b0\ x\[LeftDoubleBracket]i\[RightDoubleBracket])\
\)\^2\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)/\
\((\[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\[RightDoubleBracket] - \((\
\[Sum]\+\(i = 1\)\%n\( y\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)/\(\[Sum]\+\
\(i = 1\)\%n \
1\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\))\))\)\
\^2\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)\),
             ";", "\[IndentingNewLine]", \(\[Chi]Sqared0 = \[Sum]\+\(i = \
1\)\%n\((\(1\/\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket]\) \
\((y\[LeftDoubleBracket]i\[RightDoubleBracket] - a0 - b0\ x\
\[LeftDoubleBracket]i\[RightDoubleBracket])\))\)\^2\), ";", 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(Print["\<Errors from dataset\>"]\), ";", 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(Print["\<Number of data points: \>", 
              n]\), ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(Print[
              
              TableForm[{{"\<\>", "\<Value\>", \ "\<Error\>"}, {"\<Slope \
b\>", \ b0, \ \[CapitalDelta]b0}, {"\<y-Intercept a\>", \ 
                    a0, \ \[CapitalDelta]a0}}]]\), ";", 
            "\[IndentingNewLine]", \(Print["\<\>"]\), ";", 
            "\[IndentingNewLine]", \(Print["\<Equation of best fit: y = \>", \
\ b0, \ "\< * x + \>", \ a0]\), ";", 
            "\[IndentingNewLine]", \(Print["\<Equation of top worst fit: y = \
\>", \ b0 + \[CapitalDelta]b0, \ "\< * x + \>", \ a0 + \[CapitalDelta]a0]\), 
            ";", "\[IndentingNewLine]", \(Print["\<Equation of bottom worst \
fit: y = \>", \ b0 - \[CapitalDelta]b0, \ "\< * x + \>", \ 
              a0 - \[CapitalDelta]a0]\), ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(Print["\<\n\>", \*"\"\<Certainty Measure \
\!\(R\^2\): \>\"", \ Rsqared0]\), ";", 
            "\[IndentingNewLine]", \(Print["\<\n\>", \*"\"\<Quality of the \
Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - 2\)\): \>\"", \[Chi]Sqared0\/\(n - \
2\)]\), ";", 
            "\[IndentingNewLine]", \( (*Error\ too\ small\ if\ s\^2\  > \ 
                0, \ Error\ too\ large\ if\ s\^2\  < \ 0*) \), 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \({b \[Rule] \ 
                b0, \ \[CapitalDelta]b\  \[Rule] \ \[CapitalDelta]b0, \ 
              a \[Rule] \ 
                a0, \ \[CapitalDelta]a \[Rule] \ \[CapitalDelta]a0, \ 
              Rsqared \[Rule] \ 
                Rsqared0, \ \[Chi]Sqared\  \[Rule] \ \[Chi]Sqared0, \ 
              sSquared\  \[Rule] \[Chi]Sqared0\/\(n - 2\)\ }\)}]}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear Regression with Error Taken from Weighted Variance", \
"Subsubsection"],

Cell[BoxData[
    RowBox[{\(LinRegWeightedVariance[daten_]\), ":=", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Module", "[", 
        RowBox[{\({x, y, f, \ S\ , \[CapitalDelta]a0, \[CapitalDelta]b0, \ 
            a0, \ b0, n, Rsqared0, \ \[Chi]Sqared0}\), ",", 
          "\[IndentingNewLine]", 
          
          RowBox[{\(n = Length[daten]\), ";", 
            "\[IndentingNewLine]", \(x = Column[daten, 1]\), ";", 
            "\[IndentingNewLine]", \(y = Column[daten, \ 2]\), ";", 
            "\[IndentingNewLine]", \( (*Fuer\ die\ f\_i\ muessen\ die\ \
\[CapitalDelta]y\_i\ verwendet\ werden*) \), 
            "\[IndentingNewLine]", \(f = Column[daten, 3]\), ";", 
            "\[IndentingNewLine]", \(S = \[Sum]\+\(i = 1\)\%n\( 
                        1\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^\
2\) \(\[Sum]\+\(i = \
1\)\%n\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) - \((\[Sum]\+\(i = 1\)\%n \
x\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((f\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2)\)\^2\), ";", 
            "\[IndentingNewLine]", \(a0 = \(1\/S\) \((\[Sum]\+\(i = \
1\)\%n\(\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n y\
\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((f\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\) - \[Sum]\+\(i = 1\)\%n\( x\[LeftDoubleBracket]
                              i\[RightDoubleBracket]\/\((f\[LeftDoubleBracket]\
i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\( \
x\[LeftDoubleBracket]i\[RightDoubleBracket]\ y\[LeftDoubleBracket]i\
\[RightDoubleBracket]\)\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\
\))\)\), ";", 
            RowBox[{
              RowBox[{Cell[""], "b0"}], 
              "=", \(\(1\/S\) \((\[Sum]\+\(i = 1\)\%n\( 
                            1\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\
\)\^2\) \(\[Sum]\+\(i = 1\)\%n\( x\[LeftDoubleBracket]i\[RightDoubleBracket]\ \
y\[LeftDoubleBracket]i\[RightDoubleBracket]\)\/\((f\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\) - \[Sum]\+\(i = 1\)\%n\( x\[LeftDoubleBracket]
                              i\[RightDoubleBracket]\/\((f\[LeftDoubleBracket]\
i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\(\(\ \)\(y\
\[LeftDoubleBracket]i\[RightDoubleBracket]\)\)\/\((f\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\))\)\)}], ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]a0 = \@\(\(1\/S\) \
\(\[Sum]\+\(i = \
1\)\%n\((\(\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) \(1\/\(n - 2\)\) \
\(\[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\[RightDoubleBracket] - a0 - \
b0\ x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\))\)\)\)\), ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]b0 = \@\(\(1\/S\) \
\(\[Sum]\+\(i = 1\)\%n\((\(1\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\
\)\^2\) \(1\/\(n - 2\)\) \(\[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\
\[RightDoubleBracket] - a0 - b0\ x\[LeftDoubleBracket]i\[RightDoubleBracket])\
\)\^2\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\))\)\)\)\), ";", 
            "\[IndentingNewLine]", \(Rsqared0 = 
              1 - \((\[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\
\[RightDoubleBracket] - a0 - b0\ x\[LeftDoubleBracket]i\[RightDoubleBracket])\
\)\^2\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)/\((\[Sum]\+\(i \
= 1\)\%n\((y\[LeftDoubleBracket]i\[RightDoubleBracket] - \((\[Sum]\+\(i = 1\)\
\%n\( y\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((f\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\)/\(\[Sum]\+\(i = 1\)\%n 1\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\))\))\)\^2\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)\), ";", 
            "\[IndentingNewLine]", \(\[Chi]Sqared0 = \[Sum]\+\(i = \
1\)\%n\((\(1\/f\[LeftDoubleBracket]i\[RightDoubleBracket]\) \((y\
\[LeftDoubleBracket]i\[RightDoubleBracket] - a0 - b0\ x\[LeftDoubleBracket]i\
\[RightDoubleBracket])\))\)\^2\), ";", 
            "\[IndentingNewLine]", \(Print["\<Errors from variance\>"]\), ";",
             "\n", "\[IndentingNewLine]", \(Print["\<Number of data points: \
\>", n]\), ";", "\n", 
            "\[IndentingNewLine]", \(Print[
              TableForm[{{"\<\>", "\<Value\>", \ "\<Error\>"}, {"\<Slope \
b\>", \ b0, \ \[CapitalDelta]b0}, {"\<y-Intercept a\>", \ 
                    a0, \ \[CapitalDelta]a0}}]]\), ";", 
            "\[IndentingNewLine]", \(Print["\<\>"]\), ";", 
            "\[IndentingNewLine]", \(Print["\<Equation of best fit: y = \>", \
\ b0, \ "\< * x + \>", \ a0]\), 
            ";", \(Print["\<Equation of top worst fit: y = \>", \ 
              b0 + \[CapitalDelta]b0, \ "\< * x + \>", \ 
              a0 + \[CapitalDelta]a0]\), ";", 
            "\[IndentingNewLine]", \(Print["\<Equation of bottom worst fit: y \
= \>", \ b0 - \[CapitalDelta]b0, \ "\< * x + \>", \ a0 - \[CapitalDelta]a0]\),
             ";", "\[IndentingNewLine]", \(Print["\<\n\>", \*"\"\<Quality of \
the Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - 2\)\): \>\"", \[Chi]Sqared0\/\(n - \
2\)]\), ";", \(Print["\<\n\>", \*"\"\<Certainty Measure \!\(R\^2\): \>\"", \ 
              Rsqared0]\), ";", 
            "\n", \( (*Error\ too\ small\ if\ s\^2\  > \ 0, \ 
              Error\ too\ large\ if\ s\^2\  < \ 0*) \), "\[IndentingNewLine]",
             "\[IndentingNewLine]", \({b \[Rule] \ 
                b0, \ \[CapitalDelta]b\  \[Rule] \ \[CapitalDelta]b0, \ 
              a \[Rule] \ 
                a0, \ \[CapitalDelta]a \[Rule] \ \[CapitalDelta]a0, \ 
              Rsqared \[Rule] \ 
                Rsqared0, \ \[Chi]Sqared\  \[Rule] \ \[Chi]Sqared0, 
              sSquared\  \[Rule] \[Chi]Sqared0\/\(n - 2\)}\)}]}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear Regression for a Straight Line from the Origin", "Subsubsection"],

Cell[BoxData[
    \(LinRegOrigin[
        daten_] := \[IndentingNewLine]Module[{x, y, \[CapitalDelta]y, 
          S, \[CapitalDelta]b0, b0, n, ybar0, 
          Rsq0, \[Chi]sq0}, \[IndentingNewLine]n = 
          Length[daten]; \[IndentingNewLine]x = 
          Column[daten, 1]; \[IndentingNewLine]y = 
          Column[daten, 2]; \[IndentingNewLine]\[CapitalDelta]y = 
          Column[daten, 
            3]; \[IndentingNewLine]S = \[Sum]\+\(i = 1\)\%n 1\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2*\(\[Sum]\+\(\
i = 1\)\%n\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) - \
\((\[Sum]\+\(i = 1\)\%n x\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)\^2; \
\[IndentingNewLine]b0 = \[Sum]\+\(i = 1\)\%n\(\( x\[LeftDoubleBracket]
                      i\[RightDoubleBracket]*
                    y\[LeftDoubleBracket]
                      i\[RightDoubleBracket]\)\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)/\(\[Sum]\+\(i = 1\)\%n\((x\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)\ ; \[IndentingNewLine]\
\[CapitalDelta]b0 = 
          Sqrt[1/\(\[Sum]\+\(i = 1\)\%n\((x\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\)]; \[IndentingNewLine]ybar0 = \[Sum]\+\(i = \
1\)\%n\( y\[LeftDoubleBracket]
                    i\[RightDoubleBracket]\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)/\(\[Sum]\+\(i = 1\)\%n 1\/\
\((\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\); \
\[IndentingNewLine]Rsq0 = 
          1 - \[Sum]\+\(i = 1\)\%n\(\((y\[LeftDoubleBracket]i\
\[RightDoubleBracket] - \
b0*x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)/\(\[Sum]\+\(i = 1\)\%n\((y\
\[LeftDoubleBracket]i\[RightDoubleBracket] - ybar0)\)\^2\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\); \
\[IndentingNewLine]\[Chi]sq0 = \[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\
\[RightDoubleBracket] - \
b0*x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2; \
\[IndentingNewLine]Print["\<Errors from dataset\>"]; \
\[IndentingNewLine]Print["\<Number of data points: \>", 
          n]; \[IndentingNewLine]Print[
          TableForm[{{"\<\>", "\<Value\>", "\<Error\>"}, {"\<Slope b\>", 
                b0, \[CapitalDelta]b0}}]]; \[IndentingNewLine]Print["\<\>"]; \
\[IndentingNewLine]Print["\<Equation of best fit: y = \>", \ 
          b0, \ "\< * x\>"]; \[IndentingNewLine]Print["\<Equation of top \
worst fit: y = \>", \ 
          b0 + \[CapitalDelta]b0, \ "\< * x\>"]; \
\[IndentingNewLine]Print["\<Equation of bottom worst fit: y = \>", \ 
          b0 - \[CapitalDelta]b0, \ "\< * x\>"]; \[IndentingNewLine]Print["\<\
\>"]; \[IndentingNewLine]Print[\*"\"\<Certainty Measure \!\(R\^2\): \>\"", 
          Rsq0]; \[IndentingNewLine]Print[\*"\"\<Quality of Errors \
\!\(s\^2\)=\!\(\[Chi]\^2\/\(n - 1\)\): \>\"", \[Chi]sq0\/\(n - 1\)]; \ \
\[IndentingNewLine]{a \[Rule] 0, \[CapitalDelta]a \[Rule] \ 0, 
          b -> \ b0, \ \[CapitalDelta]b -> \[CapitalDelta]b0, 
          Rsqared -> Rsq0, \ \[Chi]Sqared\  \[Rule] \ \[Chi]sq0, 
          sSquared\  \[Rule] \[Chi]sq0\/\(n - 2\)}\[IndentingNewLine]]\)], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Instructions for Exponential Data", "Subsubsection"],

Cell["\<\
It is best to linearize exponential data first with the following \
command:\
\>", "Text"],

Cell[BoxData[
    \(\(linearize[expdata_] := 
        Replace[expdata, {xi_, yi_, \[CapitalDelta]yi_} \[Rule] \ {xi, 
              Log[yi], \((1/yi)\)*\[CapitalDelta]yi}, 2];\)\)], "Input"],

Cell["\<\
Then, you can apply the functions for linear data. If you want to \
plot the data as exponential functions later, simply raise the full right \
hand side of the fit equation into the exponent.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exporting Data", "Subsubsection"],

Cell[TextData[{
  "To export data to a file, use\n",
  Cell[BoxData[
      \(Export["\<data.csv\>", dataset, \ "\<Table\>"]\)], "Input"]
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Application", "Section"],

Cell[CellGroupData[{

Cell["Calculation", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(parameter = LinRegOrigin[dataset];\)\)], "Input"],

Cell[BoxData[
    \("Errors from dataset"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Number of data points: "\[InvisibleSpace]11\),
      SequenceForm[ "Number of data points: ", 11],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"Value\"\>", "\<\"Error\"\>"},
          {"\<\"Slope b\"\>", "1.6438009635168125`*^-6", 
            "3.251950880037854`*^-8"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equation of best fit: y = \
"\[InvisibleSpace]1.6438009635168125`*^-6\[InvisibleSpace]" * x"\),
      SequenceForm[ 
      "Equation of best fit: y = ", 1.6438009635168125*^-06, " * x"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equation of top worst fit: y = \
"\[InvisibleSpace]1.676320472317191`*^-6\[InvisibleSpace]" * x"\),
      SequenceForm[ 
      "Equation of top worst fit: y = ", 1.6763204723171911*^-06, " * x"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equation of bottom worst fit: y = \
"\[InvisibleSpace]1.611281454716434`*^-6\[InvisibleSpace]" * x"\),
      SequenceForm[ 
      "Equation of bottom worst fit: y = ", 1.611281454716434*^-06, " * x"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Certainty Measure \!\(R\^2\): \
"\[InvisibleSpace]0.9998982357712766`\),
      SequenceForm[ "Certainty Measure \!\(R\^2\): ", 0.99989823577127657],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Quality of Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - \
1\)\): "\[InvisibleSpace]0.01175156208001344`\),
      SequenceForm[ 
      "Quality of Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - 1\)\): ", 
        0.01175156208001344],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[\[IndentingNewLine]ErrorListPlot[
          dataset], \[IndentingNewLine]Plot[{b\ x + a} /. parameter // 
            Evaluate, {x, 0, Max[Column[dataset, 1]]}, 
          PlotStyle \[Rule] {Dashing[{0}]}], 
        Plot[{\((b + \[CapitalDelta]b)\) 
                    x + \((a + \[CapitalDelta]a)\), \((b - \
\[CapitalDelta]b)\) x + \((a - \[CapitalDelta]a)\)} /. parameter // 
            Evaluate, {x, 0, 
            Max[Column[dataset, 
                1]]}, \[IndentingNewLine]PlotStyle \[Rule] \
{Dashing[{0.01}]}], ImageSize \[Rule] 700, PlotLabel \[Rule] "\<dataset\>", 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 700 432.624 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0248634 33827.8 [
[.21429 .01236 -3 -9 ]
[.21429 .01236 3 0 ]
[.40476 .01236 -3 -9 ]
[.40476 .01236 3 0 ]
[.59524 .01236 -3 -9 ]
[.59524 .01236 3 0 ]
[.78571 .01236 -3 -9 ]
[.78571 .01236 3 0 ]
[.97619 .01236 -6 -9 ]
[.97619 .01236 6 0 ]
[1.025 .02486 0 -4.90625 ]
[1.025 .02486 10 4.90625 ]
[.01131 .10943 -45 -6.25 ]
[.01131 .10943 0 6.25 ]
[.01131 .194 -33 -6.25 ]
[.01131 .194 0 6.25 ]
[.01131 .27857 -45 -6.25 ]
[.01131 .27857 0 6.25 ]
[.01131 .36314 -42 -4.5 ]
[.01131 .36314 0 4.5 ]
[.01131 .44771 -54 -4.5 ]
[.01131 .44771 0 4.5 ]
[.01131 .53228 -48 -4.5 ]
[.01131 .53228 0 4.5 ]
[.01131 .61685 -54 -4.5 ]
[.01131 .61685 0 4.5 ]
[.02381 .64303 -5.03125 0 ]
[.02381 .64303 5.03125 9.8125 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .02486 m
.21429 .03111 L
s
[(2)] .21429 .01236 0 1 Mshowa
.40476 .02486 m
.40476 .03111 L
s
[(4)] .40476 .01236 0 1 Mshowa
.59524 .02486 m
.59524 .03111 L
s
[(6)] .59524 .01236 0 1 Mshowa
.78571 .02486 m
.78571 .03111 L
s
[(8)] .78571 .01236 0 1 Mshowa
.97619 .02486 m
.97619 .03111 L
s
[(10)] .97619 .01236 0 1 Mshowa
.125 Mabswid
.07143 .02486 m
.07143 .02861 L
s
.11905 .02486 m
.11905 .02861 L
s
.16667 .02486 m
.16667 .02861 L
s
.2619 .02486 m
.2619 .02861 L
s
.30952 .02486 m
.30952 .02861 L
s
.35714 .02486 m
.35714 .02861 L
s
.45238 .02486 m
.45238 .02861 L
s
.5 .02486 m
.5 .02861 L
s
.54762 .02486 m
.54762 .02861 L
s
.64286 .02486 m
.64286 .02861 L
s
.69048 .02486 m
.69048 .02861 L
s
.7381 .02486 m
.7381 .02861 L
s
.83333 .02486 m
.83333 .02861 L
s
.88095 .02486 m
.88095 .02861 L
s
.92857 .02486 m
.92857 .02861 L
s
.25 Mabswid
0 .02486 m
1 .02486 L
s
gsave
1.025 .02486 -61 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10943 m
.03006 .10943 L
s
gsave
.01131 .10943 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .194 m
.03006 .194 L
s
gsave
.01131 .194 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .27857 m
.03006 .27857 L
s
gsave
.01131 .27857 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .36314 m
.03006 .36314 L
s
[(0.00001)] .01131 .36314 1 0 Mshowa
.02381 .44771 m
.03006 .44771 L
s
[(0.0000125)] .01131 .44771 1 0 Mshowa
.02381 .53228 m
.03006 .53228 L
s
[(0.000015)] .01131 .53228 1 0 Mshowa
.02381 .61685 m
.03006 .61685 L
s
[(0.0000175)] .01131 .61685 1 0 Mshowa
.125 Mabswid
.02381 .04178 m
.02756 .04178 L
s
.02381 .05869 m
.02756 .05869 L
s
.02381 .07561 m
.02756 .07561 L
s
.02381 .09252 m
.02756 .09252 L
s
.02381 .12635 m
.02756 .12635 L
s
.02381 .14326 m
.02756 .14326 L
s
.02381 .16017 m
.02756 .16017 L
s
.02381 .17709 m
.02756 .17709 L
s
.02381 .21092 m
.02756 .21092 L
s
.02381 .22783 m
.02756 .22783 L
s
.02381 .24474 m
.02756 .24474 L
s
.02381 .26166 m
.02756 .26166 L
s
.02381 .29549 m
.02756 .29549 L
s
.02381 .3124 m
.02756 .3124 L
s
.02381 .32931 m
.02756 .32931 L
s
.02381 .34623 m
.02756 .34623 L
s
.02381 .38006 m
.02756 .38006 L
s
.02381 .39697 m
.02756 .39697 L
s
.02381 .41388 m
.02756 .41388 L
s
.02381 .4308 m
.02756 .4308 L
s
.02381 .46462 m
.02756 .46462 L
s
.02381 .48154 m
.02756 .48154 L
s
.02381 .49845 m
.02756 .49845 L
s
.02381 .51537 m
.02756 .51537 L
s
.02381 .54919 m
.02756 .54919 L
s
.02381 .56611 m
.02756 .56611 L
s
.02381 .58302 m
.02756 .58302 L
s
.02381 .59994 m
.02756 .59994 L
s
.02381 .00795 m
.02756 .00795 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66.0312 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dataset) show
105.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.02381 .01472 m
.02381 .03501 L
s
.015 w
.02381 .02486 Mdot
.002 w
.11905 .06275 m
.11905 .09658 L
s
.015 w
.11905 .07966 Mdot
.002 w
.21429 .12601 m
.21429 .15307 L
s
.015 w
.21429 .13954 Mdot
.002 w
.30952 .17607 m
.30952 .2099 L
s
.015 w
.30952 .19299 Mdot
.002 w
.40476 .23189 m
.40476 .26572 L
s
.015 w
.40476 .2488 Mdot
.002 w
.5 .28263 m
.5 .32322 L
s
.015 w
.5 .30293 Mdot
.002 w
.59524 .33642 m
.59524 .37701 L
s
.015 w
.59524 .35671 Mdot
.002 w
.69048 .3902 m
.69048 .43756 L
s
.015 w
.69048 .41388 Mdot
.002 w
.78571 .45109 m
.78571 .49169 L
s
.015 w
.78571 .47139 Mdot
.002 w
.88095 .49845 m
.88095 .54581 L
s
.015 w
.88095 .52213 Mdot
.002 w
.97619 .55596 m
.97619 .60332 L
s
.015 w
.97619 .57964 Mdot
.5 Mabswid
.02381 .02486 m
.06244 .04742 L
.10458 .07202 L
.14415 .09513 L
.18221 .11735 L
.22272 .141 L
.26171 .16377 L
.30316 .18796 L
.34309 .21128 L
.3815 .23371 L
.42237 .25757 L
.46172 .28054 L
.49955 .30263 L
.53984 .32616 L
.57861 .34879 L
.61984 .37286 L
.65954 .39605 L
.69774 .41835 L
.73838 .44208 L
.77751 .46492 L
.81909 .4892 L
.85916 .5126 L
.89771 .5351 L
.93871 .55904 L
.97619 .58093 L
s
[ .01 ] 0 setdash
.02381 .02486 m
.06244 .04787 L
.10458 .07296 L
.14415 .09652 L
.18221 .11918 L
.22272 .1433 L
.26171 .16651 L
.30316 .19119 L
.34309 .21497 L
.3815 .23784 L
.42237 .26217 L
.46172 .2856 L
.49955 .30813 L
.53984 .33212 L
.57861 .3552 L
.61984 .37975 L
.65954 .40339 L
.69774 .42613 L
.73838 .45033 L
.77751 .47363 L
.81909 .49839 L
.85916 .52224 L
.89771 .5452 L
.93871 .56961 L
.97619 .59193 L
s
.02381 .02486 m
.06244 .04697 L
.10458 .07109 L
.14415 .09374 L
.18221 .11552 L
.22272 .1387 L
.26171 .16102 L
.30316 .18474 L
.34309 .20759 L
.3815 .22957 L
.42237 .25296 L
.46172 .27548 L
.49955 .29714 L
.53984 .32019 L
.57861 .34238 L
.61984 .36598 L
.65954 .3887 L
.69774 .41056 L
.73838 .43382 L
.77751 .45622 L
.81909 .48002 L
.85916 .50295 L
.89771 .52501 L
.93871 .54848 L
.97619 .56992 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{700, 432.625},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:l0001/2000`400?l00000o`00003oo`3ooooo
0?oookh0oooo003o0?ooool0oooo_P3oool00?l0ooooo`3ooonn0?ooo`00o`3ooooo0?oookh0oooo
003o0?ooool0oooo_P3oool00?l0ooooo`3ooonn0?ooo`00o`3ooooo0?oookh0oooo003o0?ooool0
oooo_P3oool00?l0ooooo`3ooonn0?ooo`00o`3ooooo0?oookh0oooo000m0?ooo`030000003oool0
oooo0?l0ooooo`3ooomn0?ooo`00?@3oool00`000000oooo0?ooo`1c0?ooo`@00000M@3oool00`00
0000oooo0?ooo`1c0?ooo`800000MP3oool200000740oooo100000030?ooo`8000009P3oool003d0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0780
oooo00@000000?ooo`3oool00000M03oool010000000oooo0?ooo`00001b0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0S0?ooo`00?@3oool00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0780oooo1@00001c0?ooo`040000003oool0oooo000007@0oooo00@0
00000?ooo`3oool00000LP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool08`3oool003d0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1a0?ooo`040000
003oool0oooo000007@0oooo0`00001f0?ooo`800000L`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool08`3oool003d0oooo1000001e0?ooo`030000003oool0oooo0740
oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`1e0?ooo`040000003oool0oooo0000
0780oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02<0oooo000m0?oo
o`030000003oool0oooo07<0oooo00@000000?ooo`3oool00000M03oool2000007@0oooo00<00000
0?ooo`3oool0M@3oool010000000oooo0?ooo`00001`0?ooo`<000000`3oool010000000oooo0?oo
o`00000U0?ooo`00?@3oool00`000000oooo0?ooo`1d0?ooo`800000MP3oool00`000000oooo0?oo
o`1c0?ooo`<00000M@3oool2000007<0oooo00<000000?ooo`3oool00P3oool2000002H0oooo000m
0?ooo`030000003oool0oooo0?l0ooooo`3ooomn0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooOP3oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?ooogh0oooo000m0?ooo`030000
003oool0oooo0?l0ooooo`3ooomn0?ooo`00>`3oool600000?l0ooooo`3ooomm0?ooo`00>P3oool8
00000?l0ooooo`3oooml0?ooo`00>P3oool800000?l0ooooo`3ooomb0?ooo`80000000<0oooo0000
000000001@3oool003X0oooo2000003o0?ooool0ooooL`3oool00`000000oooo000000060?ooo`00
;P3ooooo00000?l00000MP00000B0?ooo`030000003oool0oooo00D0oooo000j0?ooo`P000006@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`0000001P3o
ool003X0oooo2000000I0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool07@3oool2
000000030?ooo`000000000000D0oooo000k0?ooo`H0000000<0oooo000000000000L@3oool00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0M@3oool00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo02L0oooo000m0?ooo`030000003oool0oooo00@0
oooo0P00003o0?ooool0ooooN03oool003d0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`3o0?ooool0ooooM@3oool003d0oooo00<000000?ooo`3oool01`3oool200000?l0ooooo`3o
oome0?ooo`00?@3oool00`000000oooo0?ooo`090?ooo`800000o`3ooooo0?ooog<0oooo000m0?oo
o`030000003oool0oooo00/0oooo0P00003o0?ooool0ooooL@3oool003d0oooo00<000000?ooo`3o
ool03@3oool200000?l0ooooo`3ooom_0?ooo`00?@3oool4000000d0oooo0P00003o0?ooool0oooo
KP3oool003d0oooo00<000000?ooo`3oool0403oool200000?l0ooooo`3ooom/0?ooo`00?@3oool0
0`000000oooo0?ooo`0B0?ooo`<00000o`3ooooo0?ooofT0oooo000m0?ooo`030000003oool0oooo
01@0oooo0`00003o0?ooool0ooooI`3oool003d0oooo00<000000?ooo`3oool05P3oool300000?l0
ooooo`3ooomU0?ooo`00?@3oool00`000000oooo0?ooo`0G0?ooo`<00000o`3ooooo0?ooof@0oooo
000m0?ooo`030000003oool0oooo01P0oooo0`00003o0?ooool0ooooH`3oool003d0oooo00<00000
0?ooo`3oool06`3oool200000?l0ooooo`3ooomQ0?ooo`00?@3oool00`000000oooo0?ooo`0M0?oo
o`800000o`3ooooo0?oooel0oooo000m0?ooo`030000003oool0oooo01h0oooo0`00003o0?ooool0
ooooG@3oool003d0oooo00<000000?ooo`3oool07`3oool400000?l0ooooo`3ooomK0?ooo`00?@3o
ool400000200oooo0`00003o0?ooool0ooooFP3oool003d0oooo00<000000?ooo`3oool08`3oool2
00000?l0ooooo`3ooomI0?ooo`00?@3oool00`000000oooo0?ooo`0U0?ooo`8000004P3oool00`00
0000oooo0?ooo`3o0?ooool0oooo@P3oool003d0oooo00<000000?ooo`3oool09`3oool200000100
oooo00<000000?ooo`3oool0o`3ooooo0?oood80oooo000m0?ooo`030000003oool0oooo02P0oooo
0P00000?0?ooo`030000003oool0oooo0?l0ooooo`3ooom20?ooo`00?@3oool00`000000oooo0?oo
o`0Y0?ooo`<000003@3oool00`000000oooo0?ooo`3o0?ooool0oooo@P3oool003d0oooo00<00000
0?ooo`3oool0:`3oool3000000/0oooo00<000000?ooo`3oool0o`3ooooo0?oood80oooo000m0?oo
o`030000003oool0oooo02d0oooo0`0000090?ooo`030000003oool0oooo0?l0ooooo`3ooom20?oo
o`00?@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0o`3ooooo0?oood80oooo000m0?ooo`030000003oool0oooo0340oooo0P0000040?ooo`H00000
o`3ooooo0?oood40oooo000m0?ooo`@00000<P3oool2000000030?ooo`000000000000H00000o`3o
oooo0?oood00oooo000m0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`0000002000003o
0?ooool0oooo@03oool003d0oooo00<000000?ooo`3oool0=03oool:00000?l0ooooo`3ooom00?oo
o`00?@3oool00`000000oooo0?ooo`0f0?ooo`P00000o`3ooooo0?oood00oooo000m0?ooo`030000
003oool0oooo03H0oooo2000003o0?ooool0oooo@03oool003d0oooo00<000000?ooo`3oool0=P3o
ool800000?l0ooooo`3ooom00?ooo`00?@3oool00`000000oooo0?ooo`0g0?ooo`T00000o`3ooooo
0?oooch0oooo000m0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00P3oool40000
0?l0ooooo`3oooll0?ooo`00?@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00<0
oooo1@00003o0?ooool0oooo>P3oool003d0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`050?ooo`@00000o`3ooooo0?ooocT0oooo000m0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool01`3oool200000?l0ooooo`3oooli0?ooo`00?@3oool4000003P0oooo00<00000
0?ooo`3oool02@3oool200000?l0ooooo`3ooolg0?ooo`00?@3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00/0oooo0`00003o0?ooool0oooo=03oool003d0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0=0?ooo`<00000o`3ooooo0?oooc80oooo000m0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool03P3oool400000?l0ooooo`3oool`0?ooo`00?@3o
ool00`000000oooo0?ooo`1;0?ooo`D00000o`3ooooo0?ooobh0oooo000m0?ooo`030000003oool0
oooo04d0oooo0P00003o0?ooool0oooo;`3oool003d0oooo00<000000?ooo`3oool0CP3oool30000
0?l0ooooo`3oool]0?ooo`002P3oool4000000<0oooo00<000000?ooo`3oool00P3oool3000000<0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`@000000`3oool2000000P0oooo00<000000?oo
o`3oool0D@3oool2000000030?ooo`000000oooo0?l0ooooo`3ooolX0?ooo`002P3oool00`000000
oooo0?ooo`0<0?ooo`070000003oool0oooo0?ooo`000000oooo0000000>0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05<0oooo1000
003o0?ooool0oooo9`3oool000/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0D`3oool01@000000oooo0000003oool000000?l0oooo
o`3ooolV0?ooo`00303oool00`000000oooo0?ooo`070?ooo`<00000103oool00`000000oooo0000
000>0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo05@0oooo1P00003o0?ooool0oooo903oool000d0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool5000005@0oooo1@00003o0?ooool0
oooo8`3oool000X0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0C0?ooo`<0
00000`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo05P0oooo0`00003o0?oo
ool0oooo8`3oool000/0oooo0P0000090?ooo`@00000503oool00`000000oooo0?ooo`020?ooo`80
0000203oool2000005`0oooo0P00003o0?ooool0oooo8@3oool003d0oooo00<000000?ooo`000000
G@3oool500000?l0ooooo`3ooolL0?ooo`00>03oool300000080oooo0`00001N0?ooo`<0000000<0
oooo0000003oool0o`3ooooo0?oooaX0oooo000m0?ooo`030000003oool0oooo05l0oooo0`000000
0`3oool000000000003o0?ooool0oooo6@3oool003d0oooo00<000000?ooo`3oool0H@3oool30000
00030?ooo`000000oooo0?l0ooooo`3ooolG0?ooo`00?@3oool300000680oooo1000003o0?ooool0
oooo603oool003d0oooo00<000000?ooo`3oool0I03oool010000000oooo00000000003o0?ooool0
oooo5P3oool003d0oooo00<000000?ooo`3oool0J03oool300000?l0ooooo`3ooolC0?ooo`00?@3o
ool4000006T0oooo0`0000080?ooo`030000003oool0oooo0?l0ooooo`3oool60?ooo`00?@3oool0
0`000000oooo0?ooo`1Y0?ooo`030000003oool0000000<000001P3oool00`000000oooo0?ooo`3o
0?ooool0oooo1P3oool003d0oooo00<000000?ooo`3oool0JP3oool2000000040?ooo`0000000000
000000D0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo000m0?ooo`030000003oool0oooo
06`0oooo0P0000000`3oool00000000000040?ooo`030000003oool0oooo0?l0ooooo`3oool60?oo
o`00?@3oool00`000000oooo0?ooo`1^0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0o`3ooooo0?ooo`H0oooo000m0?ooo`030000003oool0oooo0780oooo1P00003o0?ooool0
oooo1P3oool003d0oooo00<000000?ooo`3oool0L@3oool800000?l0ooooo`3oool50?ooo`00?@3o
ool00`000000oooo0?ooo`1a0?ooo`T00000o`3ooooo0?ooo`@0oooo000m0?ooo`030000003oool0
oooo0740oooo2P00003o0?ooool0oooo0`3oool003d0oooo00<000000?ooo`3oool0L@3oool80000
00030?ooo`000000oooo0?l0ooooo`3oool20?ooo`00?@3oool00`000000oooo0?ooo`1a0?ooo`T0
000000<0oooo000000000000o`3ooooo0?ooo`40oooo000m0?ooo`@00000L03oool8000000@0oooo
00@000000?ooo`3oool00000o`3ooool0?ooo`00?@3oool00`000000oooo0?ooo`1b0?ooo`H00000
1P3oool2000000030?ooo`00000000000?l0oooonP3oool003d0oooo00<000000?ooo`3oool0M@3o
ool00`000000oooo0?ooo`080?ooo`80000000<0oooo000000000000o`3ooooh0?ooo`00?@3oool0
0`000000oooo0?ooo`1e0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0?l0oooom@3oool003d0oooo00<000000?ooo`3oool0M@3oool0
0`000000oooo0?ooo`070?ooo`8000000P3oool200000?l0oooon03oool003d0oooo00<000000?oo
o`3oool0M@3oool00`000000oooo0?ooo`090?ooo`8000000P3oool00`000000oooo0?ooo`3o0?oo
ooD0oooo000m0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool02`3oool200000003
0?ooo`00000000000?l0oooom@3oool003d0oooo00<000000?ooo`3oool0R03oool2000000030?oo
o`000000oooo0?l0ooool03oool003d0oooo00<000000?ooo`3oool0RP3oool010000000oooo0000
0000003o0?ooonl0oooo000m0?ooo`030000003oool0oooo08T0oooo00D000000?ooo`0000000000
0?ooo`0200000?l0ooook@3oool003d0oooo100000290?ooo`80000000D0oooo0000003oool0oooo
0000003o0?ooon`0oooo000m0?ooo`030000003oool0oooo08`0oooo1000003o0?ooond0oooo000m
0?ooo`030000003oool0oooo08h0oooo1000003o0?ooon/0oooo000m0?ooo`030000003oool0oooo
0980oooo00D000000?ooo`3oool0oooo0000003o0?ooonH0oooo000m0?ooo`030000003oool0oooo
09<0oooo0P0000020?ooo`800000o`3ooooT0?ooo`00?@3oool00`000000oooo0?ooo`2D0?ooo`<0
00000P3oool200000?l0oooohP3oool003d0oooo00<000000?ooo`3oool0U@3oool010000000oooo
0000000000020?ooo`030000003oool0oooo0?l0oooog`3oool003d0oooo00<000000?ooo`3oool0
UP3oool2000000030?ooo`000000oooo0?l0oooohP3oool003d0oooo00<000000?ooo`3oool0V03o
ool010000000oooo00000000003o0?ooon40oooo000m0?ooo`030000003oool0oooo09T0oooo00<0
00000?ooo`3oool00P0000020?ooo`030000003oool0oooo0?l0oooofP3oool003d0oooo00<00000
0?ooo`3oool0WP3oool00`000000oooo0?ooo`02000000d0oooo00<000000?ooo`3oool0o`3oooo:
0?ooo`00?@3oool4000009h0oooo0P0000020?ooo`8000002`3oool00`000000oooo0?ooo`3o0?oo
olX0oooo000m0?ooo`030000003oool0oooo09l0oooo00@000000?ooo`00000000000P3oool20000
00T0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`00?@3oool00`000000oooo0?ooo`2P0?ooo`80
000000<0oooo0000000000002`3oool00`000000oooo0?ooo`3o0?ooolX0oooo000m0?ooo`030000
003oool0oooo0:80oooo0P0000000`3oool000000?ooo`090?ooo`030000003oool0oooo0?l0oooo
bP3oool003d0oooo00<000000?ooo`3oool0Y03oool010000000oooo0000000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0o`3oooo:0?ooo`00?@3oool00`000000oooo0?oo
o`2X0?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool0o`3oooo:0?ooo`00?@3oool0
0`000000oooo0?ooo`2Z0?ooo`8000000P3oool600000?l0oooob@3oool001H0oooo0`0000030?oo
o`050000003oool0oooo0?ooo`0000002`3oool4000000<0oooo0P0000080?ooo`030000003oool0
oooo0:X0oooo00<000000?ooo`0000002000003o0?ooolP0oooo000I0?ooo`070000003oool0oooo
0?ooo`000000oooo0000000>0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`0000001`00003o0?ooolP0oooo
000I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2/0?ooo`T00000
o`3oooo80?ooo`005P3oool3000000@0oooo00<000000?ooo`0000003P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2]0?ooo`P00000
00<0oooo0000003oool0o`3oooo50?ooo`005P3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool01@3oool500000:/0oooo200000020?ooo`800000o`3oooo40?ooo`005P3oool00`000000oooo
0?ooo`0C0?ooo`<000000`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0:d0
oooo2@0000030?ooo`030000003oool0oooo0?l0oooo`@3oool001H0oooo1000000D0?ooo`030000
003oool0oooo0080oooo0P0000080?ooo`800000[`3oool600000080oooo0P0000020?ooo`800000
o`3oooo10?ooo`00?@3oool00`000000oooo0000002`0?ooo`050000003oool0oooo0?ooo`000000
0`3oool200000080oooo00<000000?ooo`3oool0o`3ooonn0?ooo`00>03oool300000080oooo0`00
002`0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`800000o`3oooo10?ooo`00?@3oool0
0`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0
oooo0?l0oooo_P3oool003d0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`060?oo
o`8000000P3oool200000080oooo00<000000?ooo`3oool0o`3oooni0?ooo`00?@3oool300000;00
oooo00<000000?ooo`3oool0303oool2000000030?ooo`00000000000?l0oooo^@3oool003d0oooo
00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0>0?ooo`80000000<0oooo000000000000
o`3ooong0?ooo`00?@3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00`0oooo00@0
00000?ooo`3oool0oooo0P0000000`3oool000000?ooo`3o0?oookD0oooo000m0?ooo`@00000_`3o
ool2000000<0oooo00<000000?ooo`3oool0o`3ooone0?ooo`00?@3oool00`000000oooo0?ooo`32
0?ooo`8000000P3oool200000?l0oooo]@3oool003d0oooo00<000000?ooo`3oool0a03oool01000
0000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool0o`3ooon^0?ooo`00?@3oool00`00
0000oooo0?ooo`3:0?ooo`030000003oool0oooo00800000o`3ooon^0?ooo`00?@3oool00`000000
oooo0?ooo`3;0?ooo`8000000P3oool200000?l0oooo[03oool003d0oooo00<000000?ooo`3oool0
bP3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0o`3ooonY0?ooo`00?@3o
ool00`000000oooo0?ooo`3;0?ooo`040000003oool0oooo0?ooo`800000o`3ooon/0?ooo`00?@3o
ool00`000000oooo0?ooo`3<0?ooo`8000000`3oool00`000000oooo0?ooo`3o0?ooojT0oooo000m
0?ooo`030000003oool0oooo0<h0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003o
ool0oooo0?l0ooooX`3oool003d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`02
0?ooo`8000000P3oool200000?l0ooooX`3oool003d0oooo00<000000?ooo`3oool0eP3oool01000
0000oooo0?ooo`3oool200000?l0ooooX@3oool003d0oooo1000003F0?ooo`8000000`3oool00`00
0000oooo0?ooo`3o0?oooih0oooo000m0?ooo`030000003oool0oooo0=D0oooo00@000000?ooo`3o
ool0oooo0P00003o0?oooj80oooo000m0?ooo`030000003oool0oooo0=H0oooo0P0000030?ooo`80
00003`3oool00`000000oooo0?ooo`3o0?ooohh0oooo000m0?ooo`030000003oool0oooo0=P0oooo
0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`3o0?ooohh0oooo000m0?ooo`030000003oool0oooo0=X0oooo00@000000?ooo`3oool0oooo
0P0000030?ooo`8000001`3oool00`000000oooo0?ooo`3o0?ooohh0oooo000m0?ooo`030000003o
ool0oooo0>00oooo0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooohh0oooo000m
0?ooo`030000003oool0oooo0>80oooo0P0000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0o`3ooon>0?ooo`00?@3oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooohh0oooo000m0?ooo`03
0000003oool0oooo0>00oooo0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooohh0
oooo000m0?ooo`030000003oool0oooo0>80oooo0P0000030?ooo`80000000<0oooo000000000000
1000003o0?ooohd0oooo000m0?ooo`@00000h`3oool2000000<0oooo2000003o0?oooh`0oooo000m
0?ooo`030000003oool0oooo0>T0oooo2000003o0?oooh`0oooo000m0?ooo`030000003oool0oooo
0>T0oooo2@00003o0?oooh/0oooo000m0?ooo`030000003oool0oooo0>T0oooo200000000`3oool0
00000?ooo`3o0?ooohT0oooo000m0?ooo`030000003oool0oooo0>T0oooo2000003o0?oooh`0oooo
000m0?ooo`030000003oool0oooo0>T0oooo2P00003o0?ooohX0oooo000m0?ooo`030000003oool0
oooo0>X0oooo1P0000030?ooo`8000000P3oool00`000000oooo0?ooo`3o0?oooh<0oooo000m0?oo
o`030000003oool0oooo0>`0oooo00<000000?ooo`3oool00P0000040?ooo`80000000<0oooo0000
00000000o`3ooon30?ooo`00?@3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P00003o0?oooh40oooo000m0?ooo`030000003oool0oooo0>`0oooo
00<000000?ooo`3oool02@3oool200000080oooo0P00003o0?ooogl0oooo000m0?ooo`030000003o
ool0oooo0>`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`800000o`3o
oon10?ooo`00?@3oool400000>/0oooo00<000000?ooo`3oool01`3oool2000000@0oooo00<00000
0?ooo`3oool0o`3ooomn0?ooo`00?@3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo
00T0oooo0P0000030?ooo`8000000`3oool00`000000oooo0?ooo`3o0?ooogP0oooo000m0?ooo`03
0000003oool0oooo0>`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`80
00000P3oool200000?l0ooooN03oool003d0oooo00<000000?ooo`3oool0o`3oool20?ooo`040000
003oool0oooo0?ooo`800000o`3ooomf0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
0P0000030?ooo`800000o`3ooomd0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooo`40oooo00@0
00000?ooo`3oool0oooo0P00003o0?ooogL0oooo000m0?ooo`030000003oool0oooo0?l0oooo0P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooM03oool000/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000000`3oool01@000000oooo0?ooo`3o
ool0000000/0oooo100000030?ooo`800000203oool00`000000oooo0?ooo`3o0?ooo`<0oooo0P00
00030?ooo`800000103oool00`000000oooo0?ooo`3o0?ooofd0oooo000;0?ooo`030000003oool0
oooo00/0oooo00L000000?ooo`3oool0oooo0000003oool0000000h0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool50?ooo`03
0000003oool0oooo0080oooo0P0000030?ooo`800000o`3ooom]0?ooo`00303oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`800000o`3ooom[0?ooo`00
303oool00`000000oooo0?ooo`070?ooo`<00000103oool00`000000oooo0000000>0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0
oooo3@3oool2000000@0oooo0P00003o0?ooofT0oooo000=0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00D0oooo1@00003o0?ooo`d0oooo0P00003o0?oo
ofd0oooo000:0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool04`3oool30000
00<0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooofX0oooo000:0?ooo`@00000203oool40000
01@0oooo00<000000?ooo`3oool00P3oool2000000P0oooo0P00003o0?ooo`d0oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooDP3oool003d0
oooo00<000000?ooo`000000o`3oool>0?ooo`800000103oool2000000@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`3o0?oooe80oooo000h0?ooo`<000000P3oool300000?l0oooo
403oool2000000@0oooo00<000000?ooo`3oool00P3oool2000000`0oooo00<000000?ooo`3oool0
o`3ooomB0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooaL0oooo0P0000040?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`00?@3oool00`000000oooo0?ooo`3o
0?oooaT0oooo0P0000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooomB
0?ooo`00?@3oool300000?l0oooo5P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooaL0
oooo0P0000030?ooo`8000002`3oool00`000000oooo0?ooo`3o0?oooe80oooo000m0?ooo`030000
003oool0oooo0?l0oooo6@3oool2000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?l0ooooDP3oool003d0oooo1000003o0?oooaX0oooo0P00
00020?ooo`800000103oool200000080oooo00<000000?ooo`3oool0o`3ooomB0?ooo`00?@3oool0
0`000000oooo0?ooo`3o0?ooob40oooo0P0000030?ooo`H00000o`3ooomB0?ooo`00?@3oool00`00
0000oooo0?ooo`3o0?ooob<0oooo00<000000?ooo`0000001`00003o0?oooe40oooo000m0?ooo`03
0000003oool0oooo0?l0oooo903oool900000?l0ooooD@3oool003d0oooo00<000000?ooo`3oool0
o`3ooolQ0?ooo`040000003oool0oooo0?ooo`P00000o`3ooomA0?ooo`00?@3oool00`000000oooo
0?ooo`3o0?ooob80oooo0P0000000`3oool000000000000600000080oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooob@0oooo2@0000030?ooo`800000o`3o
oom<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooobD0oooo200000050?ooo`800000o`3ooom:
0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooobH0oooo1P0000000`3oool00000000000050?oo
o`030000003oool0oooo0?l0ooooA`3oool003d0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`03
0000003oool0oooo00<0oooo0P00003o0?ooodd0oooo000m0?ooo`030000003oool0oooo0?l0oooo
:@3oool010000000oooo0?ooo`0000040?ooo`800000o`3ooom;0?ooo`00?@3oool400000?l0oooo
:03oool010000000oooo0?ooo`3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0?l0
oooo@@3oool003d0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030000003oool0oooo00<0oooo
0P0000040?ooo`030000003oool0oooo00<0oooo0P00003o0?oood40oooo000m0?ooo`030000003o
ool0oooo0?l0oooo:@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P00
00050?ooo`800000o`3ooolo0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooobT0oooo00<00000
0?ooo`3oool0303oool2000000D0oooo00<000000?ooo`3oool0o`3oooll0?ooo`00?@3oool00`00
0000oooo0?ooo`3o0?ooobT0oooo00<000000?ooo`3oool03P3oool200000?l0oooo@P3oool003d0
oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00`3oool200000?l0oooo@03oool003d0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030000
003oool0oooo00/0oooo0P0000050?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooocH0oooo
000m0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`040?ooo`800000103o
ool200000?l0oooo=P3oool003d0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`8000001P3oool0
0`000000oooo0?ooo`030?ooo`800000o`3ooold0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oo
oc`0oooo00<000000?ooo`3oool0103oool2000000D0oooo00<000000?ooo`3oool0o`3ooola0?oo
o`00?@3oool400000?l0ooooA03oool200000?l0oooo=`3oool003d0oooo00<000000?ooo`3oool0
o`3ooom70?ooo`030000003oool0oooo0?l0oooo=03oool003d0oooo00<000000?ooo`3oool0o`3o
oom10?ooo`8000001@3oool200000?l0oooo=03oool003d0oooo00<000000?ooo`3oool0o`3ooom3
0?ooo`8000001@3oool2000000<0oooo00<000000?ooo`3oool0o`3oool/0?ooo`00?@3oool00`00
0000oooo0?ooo`3o0?ooodD0oooo0P0000050?ooo`8000000P3oool200000?l0oooo;03oool003d0
oooo00<000000?ooo`3oool0o`3ooom70?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool0oooo0P00000@0?ooo`030000003oool0oooo0?l0oooo5`3oool003d0oooo00<000000?ooo`3o
ool0o`3ooom?0?ooo`8000000`3oool2000000h0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`00
?@3oool00`000000oooo0?ooo`3o0?oooe40oooo0P00000A0?ooo`030000003oool0oooo0?l0oooo
5`3oool003d0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?oooaL0oooo000m0?ooo`030000003oool0
oooo0?l0ooooC@3oool00`000000oooo0?ooo`040?ooo`800000103oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0?l0oooo5`3oool003d0oooo00<000000?ooo`3oool0o`3ooom>0?oo
o`8000001P3oool2000000<0oooo0P0000070?ooo`030000003oool0oooo0?l0oooo5`3oool003d0
oooo1000003o0?ooodl0oooo00<000000?ooo`3oool01@3oool2000000<0oooo0P0000050?ooo`03
0000003oool0oooo0?l0oooo5`3oool003d0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool0
o`3ooolG0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooe/0oooo0P0000070?ooo`030000003o
ool0oooo0?l0oooo5`3oool003d0oooo00<000000?ooo`3oool0o`3ooomM0?ooo`8000000`3oool6
00000?l0oooo5P3oool003d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`0000001`00003o0?oooaD0oooo000m0?ooo`030000003oool0oooo0?l0
ooooF03oool2000000H0oooo2@00003o0?oooaD0oooo000m0?ooo`030000003oool0oooo0?l0oooo
FP3oool00`000000oooo0?ooo`040?ooo`T00000o`3ooolD0?ooo`00?@3oool00`000000oooo0?oo
o`3o0?oooe/0oooo0P0000040?ooo`P0000000<0oooo000000000000o`3ooolB0?ooo`003P3oool2
000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000040?ooo`800000103oool2
000000<0oooo100000080?ooo`030000003oool0oooo0?l0ooooH@3oool800000?l0oooo5@3oool0
00d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`P00000o`3ooolE0?oo
o`003@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool01`3oool500000?l0ooooH03oool8000000H0oooo00<000000?ooo`3o
ool0o`3oool;0?ooo`003@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooof<0oooo
0P0000050?ooo`8000001@3oool200000?l0oooo2`3oool000d0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0o`3ooomT0?ooo`<000001@3oool00`000000oooo0?ooo`040?ooo`800000o`3o
ool90?ooo`003@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo0`0000090?ooo`030000003oool0oooo0?l0ooooI03oool010000000oooo0?ooo`00
00050?ooo`8000001P3oool00`000000oooo0?ooo`3o0?ooo`H0oooo000>0?ooo`8000002P3oool2
000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3o0?ooof@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o
0?ooo``0oooo000m0?ooo`030000003oool0oooo0?l0ooooI03oool00`000000oooo0?ooo`090?oo
o`800000o`3oool<0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooof@0oooo00<000000?ooo`3o
ool02`3oool2000000L0oooo00<000000?ooo`3oool0o`3oool003d0oooo00<000000?ooo`3oool0
o`3ooomT0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0?h0oooo000m0?ooo`030000003oool0oooo0?l0ooooI03o
ool00`000000oooo0?ooo`060?ooo`8000001P3oool2000000H0oooo0P00003n0?ooo`00?@3oool0
0`000000oooo0?ooo`3o0?ooof@0oooo00<000000?ooo`3oool0203oool2000000H0oooo0P000006
0?ooo`030000003oool0oooo0?/0oooo000m0?ooo`030000003oool0oooo0?l0ooooL@3oool20000
00H0oooo0P0000050?ooo`030000003oool0oooo0?X0oooo000m0?ooo`@00000o`3ooomj0?ooo`80
0000o`3oool10?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooogd0oooo00<000000?ooo`3oool0
o@3oool003d0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`030000003oool0oooo00@0oooo0P00
00060?ooo`030000003oool0oooo0?@0oooo000m0?ooo`030000003oool0oooo0?l0ooooN03oool2
000000H0oooo0P0000050?ooo`800000m03oool003d0oooo00<000000?ooo`3oool0o`3ooomj0?oo
o`8000001P3oool2000000D0oooo0P00003b0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooog`0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0>l0
oooo000m0?ooo`030000003oool0oooo0?l0ooooQ@3oool2000001T0oooo00<000000?ooo`3oool0
fP3oool003d0oooo00<000000?ooo`3oool0o`3ooon70?ooo`8000005`3oool00`000000oooo0?oo
o`3J0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooh80oooo00<000000?ooo`3oool0103oool2
000000H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3J0?ooo`00?@3oool00`00
0000oooo0?ooo`3o0?oooh<0oooo00<000000?ooo`3oool01@3oool2000000D0oooo0P00000<0?oo
o`030000003oool0oooo0=X0oooo000m0?ooo`030000003oool0oooo0?l0ooooQ03oool2000000L0
oooo00<000000?ooo`3oool0103oool2000000X0oooo00<000000?ooo`3oool0fP3oool003d0oooo
1000003o0?ooohD0oooo00<000000?ooo`3oool01@3oool2000000H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3J0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<0
00000?ooo`3oool01P3oool2000000h0oooo00<000000?ooo`3oool0fP3oool003d0oooo00<00000
0?ooo`3oool0o`3ooonB0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0fP3oool0
03d0oooo00<000000?ooo`3oool0o`3ooonC0?ooo`8000001`3oool01@000000oooo0?ooo`3oool0
00000=`0oooo000m0?ooo`030000003oool0oooo0?l0ooooS@3oool00`000000oooo0?ooo`050?oo
o`8000001P3oool2000000030?ooo`000000oooo0=/0oooo000m0?ooo`030000003oool0oooo0?l0
ooooSP3oool2000000L0oooo00<000000?ooo`3oool01@3oool200000=`0oooo000m0?ooo`030000
003oool0oooo0?l0ooooT03oool2000000H0oooo0P0000040?ooo`H00000f@3oool003d0oooo00<0
00000?ooo`3oool0o`3ooonB0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02000
003H0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooi/0oooo2P00003H0?ooo`00?@3oool00`00
0000oooo0?ooo`3o0?oooid0oooo200000000`3oool000000?ooo`3E0?ooo`00?@3oool400000?l0
ooooUP3oool00`000000oooo0?ooo`030?ooo`P000000P3oool200000=@0oooo000m0?ooo`030000
003oool0oooo0?l0ooooV03oool2000000<0oooo200000040?ooo`800000dP3oool003d0oooo00<0
00000?ooo`3oool0o`3ooonJ0?ooo`80000000<0oooo0000000000001P0000060?ooo`800000d03o
ool003d0oooo00<000000?ooo`3oool0o`3ooonL0?ooo`T00000f03oool003d0oooo00<000000?oo
o`3oool0o`3ooonP0?ooo`030000003oool0oooo0080oooo0P00003F0?ooo`00?@3oool00`000000
oooo0?ooo`3o0?oooj00oooo00<000000?ooo`3oool0103oool200000=@0oooo000m0?ooo`030000
003oool0oooo0?l0ooooX03oool00`000000oooo0?ooo`060?ooo`8000001P3oool00`000000oooo
0?ooo`390?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooj00oooo00<000000?ooo`000000203o
ool00`000000oooo0?ooo`040?ooo`800000b@3oool003d0oooo00<000000?ooo`3oool0o`3ooonP
0?ooo`030000003oool0oooo008000001`3oool2000000H0oooo0P0000370?ooo`00?@3oool00`00
0000oooo0?ooo`3o0?oooj00oooo00<000000?ooo`3oool00P3oool2000000L0oooo0P0000060?oo
o`800000a@3oool003d0oooo00<000000?ooo`3oool0o`3ooonP0?ooo`030000003oool0oooo00@0
oooo0P0000070?ooo`030000003oool0oooo0<X0oooo000m0?ooo`@00000o`3ooonO0?ooo`030000
003oool0oooo00h0oooo0P00003:0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooj00oooo00<0
00000?ooo`3oool0403oool2000000L0oooo00<000000?ooo`3oool0_P3oool003d0oooo00<00000
0?ooo`3oool0o`3ooonP0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool2
000000H0oooo0P00002n0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oooj00oooo00<000000?oo
o`3oool02`3oool2000000L0oooo00<000000?ooo`3oool01@3oool200000;`0oooo000m0?ooo`03
0000003oool0oooo0?l0ooooX03oool00`000000oooo0?ooo`0=0?ooo`8000001P3oool2000000L0
oooo0P00002j0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oook80oooo00<000000?ooo`3oool0
1@3oool200000<40oooo000m0?ooo`030000003oool0oooo0?l0oooo_03oool200000;l0oooo000m
0?ooo`030000003oool0oooo0?l0oooo_P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0;<0oooo00020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000103oool20000
00@0oooo0P0000040?ooo`8000000`3oool400000080oooo100000020?ooo`<000002@3oool00`00
0000oooo0?ooo`3o0?oookP0oooo00<000000?ooo`3oool0103oool2000000L0oooo0P00002c0?oo
o`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0o`3oooni0?ooo`030000003oool0oooo00D0oooo0P0000070?ooo`800000/@3oool00005
0?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`D0
0000o`3ooonh0?ooo`8000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0:h0
oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`<000002@3oool00`000000
oooo0?ooo`3o0?oook`0oooo00<000000?ooo`3oool01@3oool200000;L0oooo00001@3oool00000
0?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`03
0000003oool0oooo00H0oooo0P00002e0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo0`0000030?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooolP0oooo0P0000080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0WP3oool00080oooo0P00000:0?ooo`800000
103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`800000
0`3oool4000000P0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2N0?ooo`00?@3oool00`000000oooo0?oo
o`3o0?oool80oooo00<000000?ooo`3oool01P3oool2000000L0oooo0P0000060?ooo`030000003o
ool0oooo09h0oooo000m0?ooo`030000003oool0oooo0?l0oooo``3oool2000000P0oooo0P000007
0?ooo`800000103oool00`000000oooo0?ooo`2N0?ooo`00?@3oool00`000000oooo0?ooo`3o0?oo
olD0oooo0P0000080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0WP3oool003d0
oooo00<000000?ooo`3oool0o`3oooo70?ooo`8000001`3oool2000000X0oooo00<000000?ooo`3o
ool0WP3oool003d0oooo00<000000?ooo`3oool0o`3ooooB0?ooo`800000203oool2000009l0oooo
000m0?ooo`030000003oool0oooo0?l0ooooe03oool2000000H0oooo00<000000?ooo`000000WP3o
ool003d0oooo1000003o0?oool`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`08
000009`0oooo000m0?ooo`030000003oool0oooo0?l0oooocP3oool2000000L0oooo2@0000000`3o
ool000000?ooo`2J0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooom00oooo0P0000060?ooo`P0
00000P3oool00`000000oooo0?ooo`2H0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooom80oooo
0P0000040?ooo`P00000W@3oool003d0oooo00<000000?ooo`3oool0o`3ooooH0?ooo`P00000W@3o
ool003d0oooo00<000000?ooo`3oool0o`3ooooH0?ooo`P00000203oool00`000000oooo0?ooo`2B
0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooomP0oooo2P0000070?ooo`800000TP3oool003d0
oooo00<000000?ooo`3oool0o`3ooooH0?ooo`L000000`3oool2000000L0oooo0P00002@0?ooo`00
?@3oool00`000000oooo0?ooo`3o0?ooomT0oooo0P0000000`3oool000000?ooo`060?ooo`800000
1`3oool00`000000oooo0?ooo`2=0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooom/0oooo0P00
00090?ooo`800000U@3oool003d0oooo00<000000?ooo`3oool0o`3ooooL0?ooo`8000002P3oool0
0`000000oooo0?ooo`2B0?ooo`00?@3oool400000?l0oooof`3oool00`000000oooo0?ooo`0:0?oo
o`8000001`3oool00`000000oooo0?ooo`280?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooom`0
oooo00<000000?ooo`3oool0303oool2000000H0oooo0P0000280?ooo`00?@3oool00`000000oooo
0?ooo`3o0?ooom`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`800000
1P3oool2000008H0oooo000m0?ooo`030000003oool0oooo0?l0oooog03oool00`000000oooo0?oo
o`050?ooo`8000002@3oool2000000H0oooo0P0000240?ooo`00?@3oool00`000000oooo0?ooo`3o
0?ooom`0oooo00<000000?ooo`3oool01`3oool2000000T0oooo00<000000?ooo`3oool0R@3oool0
03d0oooo00<000000?ooo`3oool0o`3ooooL0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool2000008T0oooo000m0?ooo`030000003oool0oooo0?l0oooog03oool00`000000
oooo0?ooo`0E0?ooo`8000001`3oool00`000000oooo0?ooo`1m0?ooo`00?@3oool00`000000oooo
0?ooo`3o0?ooooH0oooo00<000000?ooo`3oool01@3oool2000007d0oooo000m0?ooo`030000003o
ool0oooo0?l0ooook@3oool00`000000oooo0?ooo`070?ooo`8000001`3oool2000007/0oooo000m
0?ooo`030000003oool0oooo0?l0ooookP3oool2000000T0oooo0P0000070?ooo`800000N@3oool0
03d0oooo1000003o0?ooonl0oooo0P0000090?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0H`3oool003d0oooo00<000000?ooo`3oool0o`3oooob0?ooo`030000003oool0oooo00L0
oooo0P00000I0?ooo`030000003oool0oooo06<0oooo000m0?ooo`030000003oool0oooo0?l0oooo
l`3oool00`000000oooo0?ooo`080?ooo`800000203oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo06<0oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3oool10?ooo`030000003o
ool0oooo00H0oooo0P00000<0?ooo`030000003oool0oooo06<0oooo000m0?ooo`030000003oool0
oooo0?l0ooooo`3oool20?ooo`800000203oool2000000X0oooo00<000000?ooo`3oool0H`3oool0
03d0oooo00<000000?ooo`3oool0o`3ooooh0?ooo`030000003oool0oooo00P0oooo0P0000080?oo
o`800000203oool00`000000oooo0?ooo`1S0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooooT0
oooo0P00000:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0H`3oool003d0oooo
00<000000?ooo`3oool0o`3ooook0?ooo`8000002@3oool2000000l0oooo00<000000?ooo`3oool0
H`3oool003d0oooo00<000000?ooo`3oool0o`3oooom0?ooo`8000002@3oool2000000d0oooo00<0
00000?ooo`3oool0H`3oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`/0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000006D0oooo000m0?ooo`030000003oool0
oooo0?l0ooooo`3oool<0?ooo`8000001`3oool2000000030?ooo`000000oooo06@0oooo000m0?oo
o`@00000o`3ooooo0?ooo`<0oooo00<000000?ooo`3oool01`3oool2000000H0oooo1P00001R0?oo
o`00?@3oool00`000000oooo0?ooo`3o0?ooool0oooo1@3oool2000000T0oooo00<000000?ooo`3o
ool00P3oool800000640oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3oool70?ooo`800000
203oool200000080oooo2000001Q0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooool0oooo2@3o
ool00`000000oooo0?ooo`070?ooo`X00000H@3oool003d0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaD0oooo200000020?ooo`030000003oool0oooo05`0oooo000m0?ooo`030000003oool0oooo
0?l0ooooo`3ooolE0?ooo`P000000`3oool2000005`0oooo000m0?ooo`030000003oool0oooo0?l0
ooooo`3ooolE0?ooo`P000001@3oool2000005X0oooo000m0?ooo`030000003oool0oooo0?l0oooo
o`3oool?0?ooo`030000003oool0oooo00@0oooo1P0000080?ooo`030000003oool0oooo05L0oooo
00080?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000103oool2000000@0oooo0P00
00040?ooo`8000000`3oool400000080oooo0`0000090?ooo`030000003oool0oooo0?l0ooooo`3o
ool@0?ooo`8000001P3oool01@000000oooo0?ooo`3oool000000640oooo00070?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooooo0?oooa80oooo0P00
00040?ooo`030000003oool0oooo0080oooo0P00001O0?ooo`001`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`D00000o`3ooooo0?oooa80oooo00D000000?ooo`3oool0oooo0000
00060?ooo`8000002@3oool00`000000oooo0?ooo`1A0?ooo`001`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0oooo0`00
00090?ooo`030000003oool0oooo0?l0ooooo`3ooolH0?ooo`030000003oool0oooo00H0oooo0P00
00080?ooo`800000D@3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?oo
o`3o0?ooool0oooo603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo0P00
001?0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo0`0000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaP0oooo00<000000?ooo`0000002@3oool2000000T0oooo00<000000?ooo`3oool0C03oool0
00P0oooo0P00000:0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000001@3oool01000
0000oooo0?ooo`3oool4000000P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaP0oooo00<00000
0?ooo`3oool00P0000090?ooo`800000EP3oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaP0oooo00<000000?ooo`3oool00P3oool2000000T0oooo00<000000?ooo`3oool0D`3oool003d0
oooo00<000000?ooo`3oool0o`3ooooo0?oooaP0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`070?ooo`8000002P3oool00`000000oooo0?ooo`160?ooo`00?@3oool00`000000oooo
0?ooo`3o0?ooool0oooo603oool00`000000oooo0?ooo`0@0?ooo`8000002@3oool2000004H0oooo
000m0?ooo`030000003oool0oooo0?l0ooooo`3ooolH0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0203oool2000004@0oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3ooolH
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool2000000X0oooo00<00000
0?ooo`3oool0@@3oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?ooobD0oooo0P0000090?oo
o`800000C03oool003d0oooo1000003o0?ooool0oooo9P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo04T0oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3ooolX0?ooo`800000
2@3oool2000000/0oooo00<000000?ooo`3oool0>`3oool003d0oooo00<000000?ooo`3oool0o`3o
oooo0?ooobX0oooo00<000000?ooo`3oool0203oool2000000X0oooo00<000000?ooo`3oool0>P3o
ool003d0oooo00<000000?ooo`3oool0o`3ooooo0?ooocL0oooo00<000000?ooo`3oool0203oool2
000003X0oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3ooolh0?ooo`8000002P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo02L0oooo000m0?ooo`030000003oool0oooo0?l0
ooooo`3oool_0?ooo`030000003oool0oooo00P0oooo0P0000090?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool09`3oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?oooc00oooo
0P00000:0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool09`3oool003d0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooc80oooo0P0000090?ooo`8000005@3oool00`000000oooo0?oo
o`0W0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooool0oooo=03oool00`000000oooo0?ooo`08
0?ooo`8000002@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02L0oooo000m0?oo
o`030000003oool0oooo0?l0ooooo`3ooom10?ooo`030000003oool0oooo00L0oooo0P0000070?oo
o`030000003oool0oooo02L0oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3ooom20?ooo`80
00002@3oool2000000D0oooo00<000000?ooo`3oool09`3oool003d0oooo1000003o0?ooool0oooo
>@3oool00`000000oooo0?ooo`070?ooo`8000002@3oool2000000<0oooo00<000000?ooo`3oool0
9`3oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?oooc/0oooo00<000000?ooo`3oool0203o
ool2000000`0oooo00<000000?ooo`3oool09`3oool003d0oooo00<000000?ooo`3oool0o`3ooooo
0?oooc`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo02L0oooo000m0?ooo`030000003oool0oooo0?l0ooooo`3ooolm0?ooo`8000002P3oool20000
00T0oooo00<000000?ooo`3oool09`3oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?ooocl0
oooo00<000000?ooo`3oool02@3oool2000000D0oooo1P00000V0?ooo`00?@3oool00`000000oooo
0?ooo`3o0?ooool0ooooC@3oool010000000oooo0?ooo`3oool8000002D0oooo000m0?ooo`030000
003oool0oooo0?l0ooooo`3ooom>0?ooo`80000000<0oooo0000000000001P00000U0?ooo`00?@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooA@3oool00`000000oooo0?ooo`080?ooo`T000009@3o
ool003d0oooo00<000000?ooo`3oool0o`3ooooo0?ooodH0oooo0P0000090?ooo`P000009@3oool0
03d0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo0P0000070?ooo`P000009@3oool003d0
oooo1000003o0?ooool0ooooB@3oool00`000000oooo0?ooo`040?ooo`P000009@3oool003d0oooo
00<000000?ooo`3oool0o`3ooooo0?oooe80oooo1P00000V0?ooo`00?@3oool00`000000oooo0?oo
o`3o0?ooool0ooooE03oool00`000000oooo0?ooo`0W0?ooo`00?@3oool00`000000oooo0?ooo`3o
0?ooool0ooooC`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo000m0?oo
o`030000003oool0oooo0?l0ooooo`3ooom@0?ooo`8000000P3oool00`000000oooo0?ooo`0W0?oo
o`00?@3oool00`000000oooo0?ooo`3o0?ooool0ooooDP3oool3000002T0oooo000m0?ooo`030000
003oool0oooo0?l0ooooo`3ooomD0?ooo`030000003oool0oooo02L0oooo000m0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomD0?ooo`030000003oool0oooo02L0oooo000m0?ooo`030000003oool0
oooo0?l0ooooo`3ooomD0?ooo`030000003oool0oooo02L0oooo000m0?ooo`030000003oool0oooo
0?l0ooooo`3ooomD0?ooo`030000003oool0oooo02L0oooo000m0?ooo`030000003oool0oooo0?l0
ooooo`3ooomD0?ooo`030000003oool0oooo02L0oooo000m0?ooo`@00000o`3ooooo0?oooe<0oooo
00<000000?ooo`3oool09`3oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo00<0
00000?ooo`3oool09`3oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo00<00000
0?ooo`3oool09`3oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?ooogh0oooo000m0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomn0?ooo`00?@3oool00`000000oooo0?ooo`3o0?ooool0oooo
OP3oool003d0oooo00<000000?ooo`3oool0o`3ooooo0?ooogh0oooo000m0?ooo`030000003oool0
oooo0?l0ooooo`3ooomn0?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool00`3oool20000
00@0oooo0P0000040?ooo`800000103oool2000000<0oooo100000030?ooo`030000003oool0oooo
0080oooo0`0000090?ooo`030000003oool0oooo0?l0ooooo`3ooomn0?ooo`0000D0oooo0000003o
ool0oooo000000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooogh0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool500000?l0ooooo`3oooml0?ooo`0000D0oooo0000003oool0oooo
000000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`3oool3000000T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogh0oooo
00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000?l0ooooo`3ooon<0?ooo`0000D0
oooo0000003oool0oooo000000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo0`00
00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooooo0?ooohX0oooo
00020?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00@0
00000?ooo`3oool0oooo100000020?ooo`@00000o`3ooooo0?ooohT0oooo003o0?ooool0oooo_P3o
ool00?l0ooooo`3ooonn0?ooo`00o`3ooooo0?oookh0oooo003o0?ooool0oooo_P3oool00?l0oooo
o`3ooonn0?ooo`00o`3ooooo0?oookh0oooo003o0?ooool0oooo_P3oool00?l0ooooo`3ooonn0?oo
o`00o`3ooomF0?ooo`80000000@0oooo0000003oool0oooo0P0000000`3oool000000?ooo`020?oo
o`8000000`3oool2000000030?ooo`000000oooo00<00000103oool3000000@0oooo0P00003o0?oo
od40oooo003o0?oooeD0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000003
0?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000H0oooo00@000000?ooo`3oool00000o`3ooom00?ooo`00o`3ooomE0?ooo`04
0000003oool0oooo000000<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo0`0000030?oo
o`8000000`3oool3000000@0oooo00<000000?ooo`3oool0o`3ooom10?ooo`00o`3ooomE0?ooo`04
0000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo000000070?ooo`040000003oool0
oooo000000D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`3o0?oood40oooo
003o0?oooeH0oooo0`0000030?ooo`8000000`3oool4000000<0oooo0P0000040?ooo`<000000`3o
ool2000000<0oooo1000003o0?oood40oooo000j0?ooo`800000o`3ooolL0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?oood40oooo000l0?oo
o`030000003oool0oooo0?l0oooo603oool2000000T0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`3o0?oood40oooo000l0?ooo`800000o`3ooooo0?oooh00oooo000k0?ooo`040000
003oool0oooo00000?l0ooooo`3ooomo0?ooo`00>`3oool010000000oooo0?ooo`00003o0?ooool0
ooooO`3oool003/0oooo00@000000?ooo`3oool00000o`3ooooo0?ooogl0oooo000j0?ooo`800000
00<0oooo000000000000o`3ooooo0?ooogl0oooo003o0?ooool0oooo_P3oool00?l0ooooo`3ooonn
0?ooo`00o`3ooooo0?oookh0oooo003o0?ooool0oooo_P3oool00?l0ooooo`3ooonn0?ooo`00o`3o
oooo0?oookh0oooo003o0?ooool0oooo_P3oool00?l0ooooo`3ooonn0?ooo`00o`3ooooo0?oookh0
oooo003o0?ooool0oooo_P3oool00?l0ooooo`3ooonn0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 699}, {431.625, 0}} -> {-1.03644, -1.21315*^-6, \
0.016762, 4.71913*^-8}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 1400}, {0, 1050}},
ScreenStyleEnvironment->"Working",
WindowSize->{1396, 999},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "goerz", \
"cpprakt"}, "cpgoerz_mi_01.nb.ps", CharacterEncoding -> "iso8859-1"],
"Magnification"->1}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 34, 0, 96, "Title"],
Cell[1813, 55, 48, 3, 50, "Text"],

Cell[CellGroupData[{
Cell[1886, 62, 27, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[1938, 66, 32, 0, 28, "Subsubsection"],
Cell[1973, 68, 64, 1, 27, "Input"],
Cell[2040, 71, 66, 1, 27, "Input"],
Cell[2109, 74, 56, 1, 27, "Input"],
Cell[2168, 77, 64, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2269, 83, 64, 0, 28, "Subsubsection"],
Cell[2336, 85, 472, 9, 191, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2845, 99, 39, 0, 22, "Subsubsection"],
Cell[2887, 101, 156, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[3068, 108, 89, 1, 27, "Input"],
Cell[3160, 111, 416, 6, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3637, 124, 28, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[3690, 128, 65, 0, 28, "Subsubsection"],
Cell[3758, 130, 5952, 96, 880, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9747, 231, 84, 1, 22, "Subsubsection"],
Cell[9834, 234, 5960, 95, 866, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15831, 334, 78, 0, 22, "Subsubsection"],
Cell[15912, 336, 3561, 59, 695, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19510, 400, 58, 0, 22, "Subsubsection"],
Cell[19571, 402, 100, 3, 32, "Text"],
Cell[19674, 407, 190, 3, 27, "Input"],
Cell[19867, 412, 216, 4, 50, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[20120, 421, 39, 0, 22, "Subsubsection"],
Cell[20162, 423, 148, 4, 45, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20359, 433, 30, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[20414, 437, 36, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[20475, 441, 71, 1, 27, "Input"],
Cell[20549, 444, 54, 1, 23, "Print"],
Cell[20606, 447, 171, 3, 23, "Print"],
Cell[20780, 452, 393, 11, 43, "Print"],
Cell[21176, 465, 45, 1, 23, "Print"],
Cell[21224, 468, 259, 5, 25, "Print"],
Cell[21486, 475, 268, 5, 25, "Print"],
Cell[21757, 482, 273, 5, 25, "Print"],
Cell[22033, 489, 45, 1, 23, "Print"],
Cell[22081, 492, 221, 4, 25, "Print"],
Cell[22305, 498, 292, 6, 42, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22646, 510, 29, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[22700, 514, 680, 12, 91, "Input"],
Cell[23383, 528, 57085, 1166, 441, 10360, 586, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

